#include <iostream>
#include "poisson.h"
const int Size = 200;

const double Min = 0.0, Max = 1.0;

int main() {
    omp_set_num_threads(2); 
	__cilkrts_set_param("nworkers","2");
    // prepare problem
    Problem p(Size, Min, Max);
    std :: cout << "Problem prepared" << std :: endl;
    // time measurement
    double time;

    // 1. Serial Gauss-Seidel solver
    SerialSeidelSolver serial;
    serial.SetProblem(&p);
    time = serial.RunAndMeasure();
    std :: cout << "Serial Gauss-Seidel, time = " << time << std :: endl;

	// 2. Parallel Gauss-Seidel solver with OpenMP
	/*
    p.ReinitProblem();
    OpenMPSeidelSolver omp_s;
    omp_s.SetProblem(&p);
    time = omp_s.RunAndMeasure();
    std :: cout << "OpenMP Gauss-Seidel, time = " << time << std :: endl;
	*/
	
	// 3. Parallel Gauss-Seidel solver with Cilk
	/*
    p.ReinitProblem();
    CilkSeidelSolver cilk_s;
    cilk_s.SetProblem(&p);
    time = cilk_s.RunAndMeasure();
    std :: cout << "Cilk Seidel, time = " << time << std :: endl;
    */

	return 0;
}
